/* Rhamaa CLI Documentation - Simple Color Customization */
/* Matching the logo's teal/emerald color scheme */

:root {
  /* Colors from the logo */
  --rhamaa-primary: #1a5f5f;      /* Deep teal from logo */
  --rhamaa-secondary: #2d8080;     /* Medium teal */
  --rhamaa-accent: #40a0a0;        /* Light teal */
  --rhamaa-emerald: #059669;       /* Emerald green accent */
  --rhamaa-jade: #10b981;          /* Jade green */
}

/* Override Material Design colors for light mode */
[data-md-color-scheme="default"] {
  --md-primary-fg-color: var(--rhamaa-primary);
  --md-primary-fg-color--light: var(--rhamaa-secondary);
  --md-primary-fg-color--dark: #0d4040;
  --md-accent-fg-color: var(--rhamaa-emerald);
  --md-accent-fg-color--transparent: rgba(5, 150, 105, 0.1);
}

/* Override Material Design colors for dark mode */
[data-md-color-scheme="slate"] {
  --md-primary-fg-color: var(--rhamaa-accent);
  --md-primary-fg-color--light: #66b3b3;
  --md-primary-fg-color--dark: var(--rhamaa-secondary);
  --md-accent-fg-color: var(--rhamaa-jade);
  --md-accent-fg-color--transparent: rgba(16, 185, 129, 0.1);
}

/* Simple link color customization */
.md-typeset a {
  color: var(--rhamaa-primary);
}

.md-typeset a:hover {
  color: var(--rhamaa-secondary);
}

/* Code block accent */
.md-typeset .highlight {
  border-left: 4px solid var(--rhamaa-emerald);
}

/* Table header styling */
.md-typeset table:not([class]) th {
  background-color: var(--rhamaa-primary);
  color: white;
}

/* Inline code styling */
.md-typeset code {
  background-color: rgba(26, 95, 95, 0.1);
  color: var(--rhamaa-primary);
  border: 1px solid rgba(26, 95, 95, 0.2);
}

/* Navigation active link */
.md-nav__link--active {
  color: var(--rhamaa-primary) !important;
}

.md-nav__link:hover {
  color: var(--rhamaa-secondary) !important;
}