# Generated by RhamaaCMS CLI (Wagtail)

from django.db import migrations


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0089_log_entry_data_json_null_to_object'),
        ('utils', '0001_initial'),
    ]

    operations = [
        # Initial migration - models will be added when you run makemigrations
    ]
