"""
Settings for {{app_name}} app (Wagtail template)
This file contains app-specific settings that will be automatically
imported by RhamaaCMS auto-discovery system.
"""

# App-specific settings
{{app_name_upper}}_SETTINGS = {
    'ENABLED': True,
    'VERSION': '1.0.0',
    'DESCRIPTION': '{{app_verbose_name}} application for RhamaaCMS',
}
